/*
  Copyright 2021 Kakao Corp.

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */
package com.kakao.sdk.partner.friend

import android.content.Context
import com.kakao.sdk.partner.friend.client.PickerClient
import com.kakao.sdk.partner.friend.model.*
import io.reactivex.Single

/**
 * @suppress
 */
internal class RxFriendPickerManager {

    internal fun startActivity(
        context: Context,
        param: PickerFriendRequestParams,
        isSingle: Boolean = false,
        isPopup: Boolean = false
    ): Single<SelectedUsers> =
        Single.create<SelectedUsers> { emitter ->

            val callback: (SelectedUsers?, Throwable?) -> Unit = { users, error ->
                if (error != null) {
                    emitter.onError(error)
                } else {
                    users?.let {
                        emitter.onSuccess(users)
                    }
                }
            }

            if (isSingle) {
                if (isPopup) {
                    PickerClient.instance.selectFriendPopup(context, param, callback)
                } else {
                    PickerClient.instance.selectFriend(context, param, callback)
                }
            } else {
                if (isPopup) {
                    PickerClient.instance.selectFriendsPopup(context, param, callback)
                } else {
                    PickerClient.instance.selectFriends(context, param, callback)
                }
            }
        }

    internal fun startActivityForChat(
        context: Context,
        param: PickerChatRequestParams,
        isPopup: Boolean = false
    ): Single<Pair<SelectedUsers?, SelectedChat?>> =
        Single.create<Pair<SelectedUsers?, SelectedChat?>> { emitter ->

            val callback: (SelectedUsers?, SelectedChat?, Throwable?) -> Unit =
                { users, chat, error ->
                    if (error != null) {
                        emitter.onError(error)
                    } else {
                        emitter.onSuccess(Pair(users, chat))
                    }
                }

            if (isPopup) {
                PickerClient.instance.selectChatPopup(context, param, callback)
            } else {
                PickerClient.instance.selectChat(context, param, callback)
            }
        }

    internal fun startActivityForTab(
        context: Context,
        param: PickerTabRequestParams,
        isPopup: Boolean = false
    ): Single<Pair<SelectedUsers?, SelectedChat?>> =
        Single.create<Pair<SelectedUsers?, SelectedChat?>> { emitter ->

            val callback: (SelectedUsers?, SelectedChat?, Throwable?) -> Unit =
                { users, chat, error ->
                    if (error != null) {
                        emitter.onError(error)
                    } else {
                        emitter.onSuccess(Pair(users, chat))
                    }
                }

            if (isPopup) {
                PickerClient.instance.selectPopup(context, param, callback)
            } else {
                PickerClient.instance.select(context, param, callback)
            }
        }
}
