/*
  Copyright 2021 Kakao Corp.

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */
package com.kakao.sdk.partner.friend.client

import android.content.Context
import com.kakao.sdk.partner.friend.RxFriendPickerManager
import com.kakao.sdk.partner.friend.model.PickerChatRequestParams
import com.kakao.sdk.partner.friend.model.PickerFriendRequestParams
import com.kakao.sdk.partner.friend.model.PickerTabRequestParams
import com.kakao.sdk.partner.friend.model.SelectedUsers
import io.reactivex.Single

class RxPickerClient {

    /**
     * 여러 명의 친구를 선택(멀티 피커)할 수 있는 친구 피커를 화면 전체에 표시합니다.
     */
    fun selectFriends(
        context: Context,
        params: PickerFriendRequestParams
    ): Single<SelectedUsers> = RxFriendPickerManager().startActivity(context, params)

    /**
     * 한 명의 친구만 선택(싱글 피커)할 수 있는 친구 피커를 화면 전체에 표시합니다.
     */
    fun selectFriend(
        context: Context,
        params: PickerFriendRequestParams
    ) = RxFriendPickerManager().startActivity(context, params, isSingle = true)

    /**
     * 여러 명의 친구를 선택(멀티 피커)할 수 있는 친구 피커를 팝업 형태로 표시합니다.
     */
    fun selectFriendsPopup(
        context: Context,
        params: PickerFriendRequestParams
    ) = RxFriendPickerManager().startActivity(context, params, isPopup = true)

    /**
     * 한 명의 친구만 선택(싱글 피커)할 수 있는 친구 피커를 팝업 형태로 표시합니다.
     */
    fun selectFriendPopup(
        context: Context,
        params: PickerFriendRequestParams
    ) = RxFriendPickerManager().startActivity(context, params, isSingle = true, isPopup = true)

    /**
     * 채팅방이나 채팅방 멤버를 선택할 수 있는 채팅방 피커를 화면 전체에 표시합니다.
     */
    fun selectChat(
        context: Context,
        params: PickerChatRequestParams
    ) = RxFriendPickerManager().startActivityForChat(context, params)

    /**
     * 채팅방이나 채팅방 멤버를 선택할 수 있는 채팅방 피커를 팝업 형태로 표시합니다.
     */
    fun selectChatPopup(
        context: Context,
        params: PickerChatRequestParams
    ) = RxFriendPickerManager().startActivityForChat(context, params, isPopup = true)

    /**
     * 친구 피커와 채팅방 피커를 탭 구조로 제공하는 탭 피커를 화면 전체에 표시합니다.
     */
    fun select(
        context: Context,
        params: PickerTabRequestParams
    ) = RxFriendPickerManager().startActivityForTab(context, params)

    /**
     * 친구 피커와 채팅방 피커를 탭 구조로 제공하는 탭 피커를 팝업 형태로 표시합니다.
     */
    fun selectPopup(
        context: Context,
        params: PickerTabRequestParams
    ) = RxFriendPickerManager().startActivityForTab(context, params, isPopup = true)

    companion object {
        /**
         * 간편한 API 호출을 위해 기본 제공되는 singleton 객체
         */
        @JvmStatic
        val instance by lazy { PickerClient.rx }
    }
}

val PickerClient.Companion.rx by lazy { RxPickerClient() }