/*
  Copyright 2021 Kakao Corp.

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */
package com.kakao.sdk.partner.friend.adapter

import androidx.recyclerview.widget.DiffUtil
import com.kakao.sdk.partner.friend.internal.ChatItem
import com.kakao.sdk.partner.friend.internal.FriendItem
import com.kakao.sdk.partner.friend.internal.Item

/**
 * @suppress
 */
internal class ItemDiffUtilCallback : DiffUtil.Callback() {
    private lateinit var oldList: List<Item>
    private lateinit var newList: List<Item>

    override fun getOldListSize(): Int = oldList.size
    override fun getNewListSize(): Int = newList.size

    fun setLists(oldList: List<Item>, newList: List<Item>) {
        this.oldList = oldList
        this.newList = newList
    }

    override fun areItemsTheSame(oldItemPosition: Int, newItemPosition: Int): Boolean {
        return oldList[oldItemPosition].hashCode() == newList[newItemPosition].hashCode()
    }

    override fun areContentsTheSame(oldItemPosition: Int, newItemPosition: Int): Boolean {
        val oldItem = oldList[oldItemPosition]
        val newItem = newList[newItemPosition]
        when (oldItem) {
            is Item.Header -> {
                if (newItem !is Item.Header) {
                    return false
                }
                return oldItem.title == newItem.title
            }
            is Item.Divider -> {
                if (newItem !is Item.Divider) {
                    return false
                }
                return true
            }
            is Item.EmptySearchResult -> {
                if (newItem !is Item.EmptySearchResult) {
                    return false
                }
                return true
            }
            is FriendItem.User -> {
                if (newItem !is FriendItem.User) {
                    return false
                }
                return oldItem.uuid == newItem.uuid
            }
            is ChatItem.Chat -> {
                if (newItem !is ChatItem.Chat) {
                    return false
                }
                return oldItem.id == newItem.id
            }
            else -> return false
        }
    }
}