/*
  Copyright 2021 Kakao Corp.

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */
package com.kakao.sdk.partner.friend.internal

import com.kakao.sdk.partner.friend.model.DisableSelectOption
import com.kakao.sdk.partner.friend.model.PickerChatType
import com.kakao.sdk.partner.friend.util.FilterSearchable

/**
 * @suppress
 */
internal sealed class Item {
    data class Header(val title: String) : Item()
    object Divider : Item()
    object EmptySearchResult : Item()
}

/**
 * @suppress
 */
internal sealed class FriendItem : Item() {
    data class User(
        val id: Long?,
        val uuid: String?,
        val nickname: String?,
        val profileImageUrl: String?,
        val disableSelectOptions: List<DisableSelectOption>? = null,
        val favorite: Boolean? = null,
        var isChecked: Boolean = false,
        val isStoryFriendOnly: Boolean = false,
        val appRegistered: Boolean? = true // me의 응답으로는 appRegistered가 오지 않고, 가입자만 친구 피커를 사용할 수 있으므로 기본값이 true
    ) : FriendItem(), FilterSearchable {
        override fun equals(other: Any?): Boolean {
            if (other is User) {
                return uuid == other.uuid
            }
            return super.equals(other)
        }

        override fun hashCode(): Int {
            return super.hashCode()
        }

        override val filterKeyword: String
            get() = nickname ?: ""
    }
}

/**
 * @suppress
 */
internal sealed class ChatItem : Item() {
    data class SelectAll(var isChecked: Boolean = false) : ChatItem()
    data class Chat(
        val id: Long,
        val title: String?,
        val titleSource: String?,
        val imageUrl: String?,
        val memberCount: Int? = 0,
        val displayMemberImages: List<String>? = null,
        var chatType: PickerChatType?,
        var isChecked: Boolean = false
    ) : ChatItem(), FilterSearchable {
        override fun equals(other: Any?): Boolean {
            if (other is Chat) {
                return id == other.id
            }
            return super.equals(other)
        }

        override fun hashCode(): Int {
            return super.hashCode()
        }

        override val filterKeyword: String
            get() = title ?: ""
    }
}
