/*
  Copyright 2021 Kakao Corp.

  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at

     http://www.apache.org/licenses/LICENSE-2.0

  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */
package com.kakao.sdk.partner.friend.util

import android.content.Context
import android.content.res.Configuration
import com.kakao.sdk.v2.partner.friend.R

/**
 * @suppress
 */
internal object LayoutUtils {
    var pickerWidth = 0
        private set
    var pickerHeight = 0
        private set
    var orientation = Configuration.ORIENTATION_PORTRAIT
        private set
    var isPopup = false
        private set

    fun initialize(context: Context, isPopup: Boolean) {
        this.isPopup = isPopup
        orientation = context.resources.configuration.orientation

        var statusBar = 0
        val resId = context.resources.getIdentifier("status_bar_height", "dimen", "android");
        if (resId > 0) {
            statusBar = context.resources.getDimensionPixelSize(resId);
        }

        val widthPixels = context.resources.displayMetrics.widthPixels
        val heightPixels = context.resources.displayMetrics.heightPixels - statusBar // 상태바를 높이에서 제외

        val minMargin = if (orientation == Configuration.ORIENTATION_PORTRAIT) {
            2 * context.resources.getDimensionPixelSize(R.dimen.popup_min_margin)
        } else {
            2 * context.resources.getDimensionPixelSize(R.dimen.popup_min_margin_landscape)
        }
        val minMarginWidth = (widthPixels - minMargin)
        val minMarginHeight = (heightPixels - minMargin)
        val maxPopupWidth =
            context.resources.getDimensionPixelSize(R.dimen.popup_max_width)
        val maxPopupHeight =
            context.resources.getDimensionPixelSize(R.dimen.popup_max_height)
        pickerWidth = if (!isPopup) widthPixels else {
            if (maxPopupWidth + minMargin > widthPixels) minMarginWidth else maxPopupWidth
        }
        pickerHeight = if (!isPopup) heightPixels else {
            if (maxPopupHeight + minMargin > heightPixels) minMarginHeight else maxPopupHeight
        }
    }
}
