/*
  Copyright 2021 Kakao Corp.
  Licensed under the Apache License, Version 2.0 (the "License");
  you may not use this file except in compliance with the License.
  You may obtain a copy of the License at
     http://www.apache.org/licenses/LICENSE-2.0
  Unless required by applicable law or agreed to in writing, software
  distributed under the License is distributed on an "AS IS" BASIS,
  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
  See the License for the specific language governing permissions and
  limitations under the License.
 */
package com.kakao.sdk.partner.friend.util

import android.os.Parcelable
import com.kakao.sdk.partner.friend.internal.ViewSettingParams
import com.kakao.sdk.partner.friend.model.*

internal object ParameterConverter {
    @JvmStatic
    fun Parcelable.toViewSettingParams(): ViewSettingParams {
        val viewAppearance: ViewAppearance?
        val orientation: PickerOrientation?
        when (this) {
            is PickerFriendRequestParams -> {
                viewAppearance = this.viewAppearance
                orientation = this.orientation
            }
            is PickerChatRequestParams -> {
                viewAppearance = this.viewAppearance
                orientation = this.orientation
            }
            is PickerTabRequestParams -> {
                viewAppearance = this.viewAppearance
                orientation = this.orientation
            }
            else -> throw IllegalArgumentException()
        }
        return ViewSettingParams(viewAppearance, orientation)
    }

    fun PickerTabRequestParams.toPickerFriendRequestParams() = PickerFriendRequestParams(
        title = this.title,
        viewAppearance = this.viewAppearance,
        orientation = this.orientation,
        enableSearch = this.enableSearch,
        disableSelectOptions = this.disableSelectOptions,
        maxPickableCount = this.maxPickableCount,
        minPickableCount = this.minPickableCount,
        displayAllProfile = this.displayAllProfile,
        friendOrder = this.friendsParams.friendOrder,
        serviceTypeFilter = this.friendsParams.serviceTypeFilter,
        friendFilter = this.friendsParams.friendFilter,
        countryCodeFilters = this.friendsParams.countryCodeFilters,
        usingOsFilter = this.friendsParams.usingOsFilter,
        enableIndex = this.friendsParams.enableIndex,
        showMyProfile = this.friendsParams.showMyProfile,
        showFavorite = this.friendsParams.showFavorite,
        showPickedFriend = this.friendsParams.showPickedFriend
    )

    fun PickerTabRequestParams.toPickerChatRequestParams() = PickerChatRequestParams(
        title = this.title,
        viewAppearance = this.viewAppearance,
        orientation = this.orientation,
        enableSearch = this.enableSearch,
        displayAllProfile = this.displayAllProfile,
        disableSelectOptions = this.disableSelectOptions,
        maxPickableCount = this.maxPickableCount,
        minPickableCount = this.minPickableCount,
        selectionType = this.chatParams.selectionType,
        chatFilters = this.chatParams.chatFilters
    )
}